@@ -55,6 +55,54 @@ ApiListener::ApiListener(void)
 	m_SyncQueue.SetName("ApiListener, SyncQueue");
 }
 
+String ApiListener::GetApiDir(void)
+{
+	return Application::GetLocalStateDir() + "/lib/icinga2/api/";
+}
+
+String ApiListener::GetCertsDir(void)
+{
+	return Application::GetLocalStateDir() + "/lib/icinga2/certs/";
+}
+
+String ApiListener::GetCaDir(void)
+{
+	return Application::GetLocalStateDir() + "/lib/icinga2/ca/";
+}
+
+String ApiListener::GetCertificateRequestsDir(void)
+{
+	return Application::GetLocalStateDir() + "/lib/icinga2/certificate-requests/";
+}
+
+String ApiListener::GetDefaultCertPath(void)
+{
+	return GetCertsDir() + "/" + ScriptGlobal::Get("NodeName") + ".crt";
+}
+
+String ApiListener::GetDefaultKeyPath(void)
+{
+	return GetCertsDir() + "/" + ScriptGlobal::Get("NodeName") + ".key";
+}
+
+String ApiListener::GetDefaultCaPath(void)
+{
+	return GetCertsDir() + "/ca.crt";
+}
+
+void ApiListener::CopyCertificateFile(const String& oldCertPath, const String& newCertPath)
+{
+	struct stat st1, st2;
+
+	if (!oldCertPath.IsEmpty() && stat(oldCertPath.CStr(), &st1) >= 0 && (stat(newCertPath.CStr(), &st2) < 0 || st1.st_mtime > st2.st_mtime)) {
+		Log(LogWarning, "ApiListener")
+		    << "Copying '" << oldCertPath << "' certificate file to '" << newCertPath << "'";
+
+		Utility::MkDirP(Utility::DirName(newCertPath), 0700);
+		Utility::CopyFile(oldCertPath, newCertPath);
+	}
+}
+
 void ApiListener::OnConfigLoaded(void)
 {
 	if (m_Instance)
@@ -62,35 +110,59 @@ void ApiListener::OnConfigLoaded(void)
 
 	m_Instance = this;
 
+	String defaultCertPath = GetDefaultCertPath();
+	String defaultKeyPath = GetDefaultKeyPath();
+	String defaultCaPath = GetDefaultCaPath();
+
+	/* Migrate certificate location < 2.8 to the new default path. */
+	String oldCertPath = GetCertPath();
+	String oldKeyPath = GetKeyPath();
+	String oldCaPath = GetCaPath();
+
+	CopyCertificateFile(oldCertPath, defaultCertPath);
+	CopyCertificateFile(oldKeyPath, defaultKeyPath);
+	CopyCertificateFile(oldCaPath, defaultCaPath);
+
+	if (!oldCertPath.IsEmpty() && !oldKeyPath.IsEmpty() && !oldCaPath.IsEmpty()) {
+		Log(LogWarning, "ApiListener", "Please read the upgrading documentation for v2.8: https://www.icinga.com/docs/icinga2/latest/doc/16-upgrading-icinga-2/");
+	}
+
 	/* set up SSL context */
 	boost::shared_ptr<X509> cert;
 	try {
-		cert = GetX509Certificate(GetCertPath());
+		cert = GetX509Certificate(defaultCertPath);
 	} catch (const std::exception&) {
 		BOOST_THROW_EXCEPTION(ScriptError("Cannot get certificate from cert path: '"
-		    + GetCertPath() + "'.", GetDebugInfo()));
+		    + defaultCertPath + "'.", GetDebugInfo()));
 	}
 
 	try {
 		SetIdentity(GetCertificateCN(cert));
 	} catch (const std::exception&) {
 		BOOST_THROW_EXCEPTION(ScriptError("Cannot get certificate common name from cert path: '"
-		    + GetCertPath() + "'.", GetDebugInfo()));
+		    + defaultCertPath + "'.", GetDebugInfo()));
 	}
 
 	Log(LogInformation, "ApiListener")
 	    << "My API identity: " << GetIdentity();
 
+	UpdateSSLContext();
+}
+
+void ApiListener::UpdateSSLContext(void)
+{
+	boost::shared_ptr<SSL_CTX> context;
+
 	try {
-		m_SSLContext = MakeSSLContext(GetCertPath(), GetKeyPath(), GetCaPath());
+		context = MakeSSLContext(GetDefaultCertPath(), GetDefaultKeyPath(), GetDefaultCaPath());
 	} catch (const std::exception&) {
 		BOOST_THROW_EXCEPTION(ScriptError("Cannot make SSL context for cert path: '"
-		    + GetCertPath() + "' key path: '" + GetKeyPath() + "' ca path: '" + GetCaPath() + "'.", GetDebugInfo()));
+		    + GetDefaultCertPath() + "' key path: '" + GetDefaultKeyPath() + "' ca path: '" + GetDefaultCaPath() + "'.", GetDebugInfo()));
 	}
 
 	if (!GetCrlPath().IsEmpty()) {
 		try {
-			AddCRLToSSLContext(m_SSLContext, GetCrlPath());
+			AddCRLToSSLContext(context, GetCrlPath());
 		} catch (const std::exception&) {
 			BOOST_THROW_EXCEPTION(ScriptError("Cannot add certificate revocation list to SSL context for crl path: '"
 			    + GetCrlPath() + "'.", GetDebugInfo()));
@@ -99,7 +171,7 @@ void ApiListener::OnConfigLoaded(void)
 
 	if (!GetCipherList().IsEmpty()) {
 		try {
-			SetCipherListToSSLContext(m_SSLContext, GetCipherList());
+			SetCipherListToSSLContext(context, GetCipherList());
 		} catch (const std::exception&) {
 			BOOST_THROW_EXCEPTION(ScriptError("Cannot set cipher list to SSL context for cipher list: '"
 			    + GetCipherList() + "'.", GetDebugInfo()));
@@ -108,11 +180,23 @@ void ApiListener::OnConfigLoaded(void)
 
 	if (!GetTlsProtocolmin().IsEmpty()){
 		try {
-			SetTlsProtocolminToSSLContext(m_SSLContext, GetTlsProtocolmin());
+			SetTlsProtocolminToSSLContext(context, GetTlsProtocolmin());
 		} catch (const std::exception&) {
 			BOOST_THROW_EXCEPTION(ScriptError("Cannot set minimum TLS protocol version to SSL context with tls_protocolmin: '" + GetTlsProtocolmin() + "'.", GetDebugInfo()));
 		}
 	}
+
+	m_SSLContext = context;
+
+	for (const Endpoint::Ptr& endpoint : ConfigType::GetObjectsByType<Endpoint>()) {
+		for (const JsonRpcConnection::Ptr& client : endpoint->GetClients()) {
+			client->Disconnect();
+		}
+	}
+
+	for (const JsonRpcConnection::Ptr& client : m_AnonymousClients) {
+		client->Disconnect();
+	}
 }
 
 void ApiListener::OnAllConfigLoaded(void)
@@ -165,6 +249,12 @@ void ApiListener::Start(bool runtimeCreated)
 	m_AuthorityTimer->SetInterval(30);
 	m_AuthorityTimer->Start();
 
+	m_CleanupCertificateRequestsTimer = new Timer();
+	m_CleanupCertificateRequestsTimer->OnTimerExpired.connect(boost::bind(&ApiListener::CleanupCertificateRequestsTimerHandler, this));
+	m_CleanupCertificateRequestsTimer->SetInterval(3600);
+	m_CleanupCertificateRequestsTimer->Start();
+	m_CleanupCertificateRequestsTimer->Reschedule(0);
+
 	OnMasterChanged(true);
 }
 
@@ -184,11 +274,6 @@ ApiListener::Ptr ApiListener::GetInstance(void)
 	return m_Instance;
 }
 
-boost::shared_ptr<SSL_CTX> ApiListener::GetSSLContext(void) const
-{
-	return m_SSLContext;
-}
-
 Endpoint::Ptr ApiListener::GetMaster(void) const
 {
 	Zone::Ptr zone = Zone::GetLocalZone();
@@ -294,7 +379,7 @@ void ApiListener::AddConnection(const Endpoint::Ptr& endpoint)
 	String port = endpoint->GetPort();
 
 	Log(LogInformation, "ApiListener")
-	    << "Reconnecting to API endpoint '" << endpoint->GetName() << "' via host '" << host << "' and port '" << port << "'";
+	    << "Reconnecting to endpoint '" << endpoint->GetName() << "' via host '" << host << "' and port '" << port << "'";
 
 	TcpSocket::Ptr client = new TcpSocket();
 
@@ -313,6 +398,9 @@ void ApiListener::AddConnection(const Endpoint::Ptr& endpoint)
 		Log(LogDebug, "ApiListener")
 		    << info.str() << "\n" << DiagnosticInformation(ex);
 	}
+
+	Log(LogInformation, "ApiListener")
+	    << "Finished reconnecting to endpoint '" << endpoint->GetName() << "' via host '" << host << "' and port '" << port << "'";
 }
 
 void ApiListener::NewClientHandler(const Socket::Ptr& client, const String& hostname, ConnectionRole role)
@@ -321,6 +409,9 @@ void ApiListener::NewClientHandler(const Socket::Ptr& client, const String& host
 		NewClientHandlerInternal(client, hostname, role);
 	} catch (const std::exception& ex) {
 		Log(LogCritical, "ApiListener")
+		    << "Exception while handling new API client connection: " << DiagnosticInformation(ex, false);
+
+		Log(LogDebug, "ApiListener")
 		    << "Exception while handling new API client connection: " << DiagnosticInformation(ex);
 	}
 }
@@ -374,7 +465,7 @@ void ApiListener::NewClientHandlerInternal(const Socket::Ptr& client, const Stri
 			identity = GetCertificateCN(cert);
 		} catch (const std::exception&) {
 			Log(LogCritical, "ApiListener")
-			    << "Cannot get certificate common name from cert path: '" << GetCertPath() << "'.";
+			    << "Cannot get certificate common name from cert path: '" << GetDefaultCertPath() << "'.";
 			return;
 		}
 
@@ -389,7 +480,6 @@ void ApiListener::NewClientHandlerInternal(const Socket::Ptr& client, const Stri
 				Log(LogWarning, "ApiListener")
 					<< "Certificate validation failed for endpoint '" << hostname
 					<< "': " << tlsStream->GetVerifyError();
-				return;
 			}
 		}
 
@@ -463,6 +553,8 @@ void ApiListener::NewClientHandlerInternal(const Socket::Ptr& client, const Stri
 
 void ApiListener::SyncClient(const JsonRpcConnection::Ptr& aclient, const Endpoint::Ptr& endpoint, bool needSync)
 {
+	Zone::Ptr eZone = endpoint->GetZone();
+
 	try {
 		{
 			ObjectLock olock(endpoint);
@@ -470,20 +562,36 @@ void ApiListener::SyncClient(const JsonRpcConnection::Ptr& aclient, const Endpoi
 			endpoint->SetSyncing(true);
 		}
 
+		Zone::Ptr myZone = Zone::GetLocalZone();
+
+		if (myZone->GetParent() == eZone) {
+			Log(LogInformation, "ApiListener")
+			    << "Requesting new certificate for this Icinga instance from endpoint '" << endpoint->GetName() << "'.";
+
+			JsonRpcConnection::SendCertificateRequest(aclient, MessageOrigin::Ptr(), String());
+
+			if (Utility::PathExists(ApiListener::GetCertificateRequestsDir()))
+				Utility::Glob(ApiListener::GetCertificateRequestsDir() + "/*.json", boost::bind(&JsonRpcConnection::SendCertificateRequest, aclient, MessageOrigin::Ptr(), _1), GlobFile);
+		}
+
 		/* Make sure that the config updates are synced
 		 * before the logs are replayed.
 		 */
 
 		Log(LogInformation, "ApiListener")
-		    << "Sending config updates for endpoint '" << endpoint->GetName() << "'.";
+		    << "Sending config updates for endpoint '" << endpoint->GetName() << "' in zone '" << eZone->GetName() << "'.";
 
 		/* sync zone file config */
 		SendConfigUpdate(aclient);
+
+		Log(LogInformation, "ApiListener")
+		    << "Finished sending config file updates for endpoint '" << endpoint->GetName() << "' in zone '" << eZone->GetName() << "'.";
+
 		/* sync runtime config */
 		SendRuntimeConfigObjects(aclient);
 
 		Log(LogInformation, "ApiListener")
-		    << "Finished sending config updates for endpoint '" << endpoint->GetName() << "'.";
+		    << "Finished sending runtime config updates for endpoint '" << endpoint->GetName() << "' in zone '" << eZone->GetName() << "'.";
 
 		if (!needSync) {
 			ObjectLock olock2(endpoint);
@@ -492,22 +600,30 @@ void ApiListener::SyncClient(const JsonRpcConnection::Ptr& aclient, const Endpoi
 		}
 
 		Log(LogInformation, "ApiListener")
-		    << "Sending replay log for endpoint '" << endpoint->GetName() << "'.";
+		    << "Sending replay log for endpoint '" << endpoint->GetName() << "' in zone '" << eZone->GetName() << "'.";
 
 		ReplayLog(aclient);
 
-		if (endpoint->GetZone() == Zone::GetLocalZone())
+		if (eZone == Zone::GetLocalZone())
 			UpdateObjectAuthority();
 
 		Log(LogInformation, "ApiListener")
-		    << "Finished sending replay log for endpoint '" << endpoint->GetName() << "'.";
+		    << "Finished sending replay log for endpoint '" << endpoint->GetName() << "' in zone '" << eZone->GetName() << "'.";
 	} catch (const std::exception& ex) {
-		ObjectLock olock2(endpoint);
-		endpoint->SetSyncing(false);
+		{
+			ObjectLock olock2(endpoint);
+			endpoint->SetSyncing(false);
+		}
 
 		Log(LogCritical, "ApiListener")
+		    << "Error while syncing endpoint '" << endpoint->GetName() << "': " << DiagnosticInformation(ex, false);
+
+		Log(LogDebug, "ApiListener")
 		    << "Error while syncing endpoint '" << endpoint->GetName() << "': " << DiagnosticInformation(ex);
 	}
+
+	Log(LogInformation, "ApiListener")
+	    << "Finished syncing endpoint '" << endpoint->GetName() << "' in zone '" << eZone->GetName() << "'.";
 }
 
 void ApiListener::ApiTimerHandler(void)
@@ -577,7 +693,6 @@ void ApiListener::ApiTimerHandler(void)
 		    << "Setting log position for identity '" << endpoint->GetName() << "': "
 		    << Utility::FormatDateTime("%Y/%m/%d %H:%M:%S", ts);
 	}
-
 }
 
 void ApiListener::ApiReconnectTimerHandler(void)
@@ -649,6 +764,33 @@ void ApiListener::ApiReconnectTimerHandler(void)
 	    << "Connected endpoints: " << Utility::NaturalJoin(names);
 }
 
+static void CleanupCertificateRequest(const String& path, double expiryTime)
+{
+#ifndef _WIN32
+	struct stat statbuf;
+	if (lstat(path.CStr(), &statbuf) < 0)
+		return;
+#else /* _WIN32 */
+	struct _stat statbuf;
+	if (_stat(path.CStr(), &statbuf) < 0)
+		return;
+#endif /* _WIN32 */
+
+	if (statbuf.st_mtime < expiryTime)
+		(void) unlink(path.CStr());
+}
+
+void ApiListener::CleanupCertificateRequestsTimerHandler(void)
+{
+	String requestsDir = GetCertificateRequestsDir();
+
+	if (Utility::PathExists(requestsDir)) {
+		/* remove certificate requests that are older than a week */
+		double expiryTime = Utility::GetTime() - 7 * 24 * 60 * 60;
+		Utility::Glob(requestsDir + "/*.json", boost::bind(&CleanupCertificateRequest, _1, expiryTime), GlobFile);
+	}
+}
+
 void ApiListener::RelayMessage(const MessageOrigin::Ptr& origin,
     const ConfigObject::Ptr& secobj, const Dictionary::Ptr& message, bool log)
 {
@@ -843,11 +985,6 @@ void ApiListener::SyncRelayMessage(const MessageOrigin::Ptr& origin,
 		PersistMessage(message, secobj);
 }
 
-String ApiListener::GetApiDir(void)
-{
-	return Application::GetLocalStateDir() + "/lib/icinga2/api/";
-}
-
 /* must hold m_LogLock */
 void ApiListener::OpenLogFile(void)
 {
@@ -1011,7 +1148,11 @@ void ApiListener::ReplayLog(const JsonRpcConnection::Ptr& client)
 					count++;
 				} catch (const std::exception& ex) {
 					Log(LogWarning, "ApiListener")
+					    << "Error while replaying log for endpoint '" << endpoint->GetName() << "': " << DiagnosticInformation(ex, false);
+
+					Log(LogDebug, "ApiListener")
 					    << "Error while replaying log for endpoint '" << endpoint->GetName() << "': " << DiagnosticInformation(ex);
+
 					break;
 				}
 
@@ -1213,37 +1354,37 @@ double ApiListener::CalculateZoneLag(const Endpoint::Ptr& endpoint)
 
 void ApiListener::AddAnonymousClient(const JsonRpcConnection::Ptr& aclient)
 {
-	ObjectLock olock(this);
+	boost::mutex::scoped_lock(m_AnonymousClientsLock);
 	m_AnonymousClients.insert(aclient);
 }
 
 void ApiListener::RemoveAnonymousClient(const JsonRpcConnection::Ptr& aclient)
 {
-	ObjectLock olock(this);
+	boost::mutex::scoped_lock(m_AnonymousClientsLock);
 	m_AnonymousClients.erase(aclient);
 }
 
 std::set<JsonRpcConnection::Ptr> ApiListener::GetAnonymousClients(void) const
 {
-	ObjectLock olock(this);
+	boost::mutex::scoped_lock(m_AnonymousClientsLock);
 	return m_AnonymousClients;
 }
 
 void ApiListener::AddHttpClient(const HttpServerConnection::Ptr& aclient)
 {
-	ObjectLock olock(this);
+	boost::mutex::scoped_lock(m_HttpClientsLock);
 	m_HttpClients.insert(aclient);
 }
 
 void ApiListener::RemoveHttpClient(const HttpServerConnection::Ptr& aclient)
 {
-	ObjectLock olock(this);
+	boost::mutex::scoped_lock(m_HttpClientsLock);
 	m_HttpClients.erase(aclient);
 }
 
 std::set<HttpServerConnection::Ptr> ApiListener::GetHttpClients(void) const
 {
-	ObjectLock olock(this);
+	boost::mutex::scoped_lock(m_HttpClientsLock);
 	return m_HttpClients;
 }
 
